==> expressworks-3.4.1.tgz: package/exercises/good_old_form/exercise.js <==
var qs            = require('querystring')
  , through2      = require('through2')
  , superagent    = require('superagent')
  , exercise      = require('workshopper-exercise')()
  , filecheck     = require('workshopper-exercise/filecheck')
  , execute       = require('workshopper-exercise/execute')
  , comparestdout = require('workshopper-exercise/comparestdout')
  , rndport       = require('../../lib/rndport');

// checks that the submission file actually exists
exercise = filecheck(exercise)

// execute the solution and submission in parallel with spawn()
exercise = execute(exercise)

// set up ports to be passed to submission and solution
exercise.addSetup(function(mode, callback) {
  this.submissionPort = rndport()
  this.solutionPort   = this.submissionPort + 1

  this.submissionArgs = [this.submissionPort]
  this.solutionArgs   = [this.solutionPort]

  process.nextTick(callback)
})

// add a processor for both run and verify calls, added *before*
// the comparestdout processor so we can mess with the stdouts
exercise.addProcessor(function (mode, callback) {
  this.submissionStdout.pipe(process.stdout)

  // replace stdout with our own streams
  this.submissionStdout = through2()
  if (mode == 'verify')
    this.solutionStdout = through2()

  setTimeout(query.bind(this, mode), 1500)

  process.nextTick(function () {
    callback(null, true)
  })
})


// compare stdout of solution and submission
exercise = comparestdout(exercise)

// delayed for 500ms to wait for servers to start so we can start
// playing with them
function query (mode) {
  var exercise = this

  function connect (port, stream) {
    var url = 'http://localhost:' + port + '/form'
    var text = exercise.__('exercises.good_old_form.source').split('').reverse().join('');

    superagent
      .post(url)
      .type('form')
      .send({str: text})
      .pipe(stream)
  }

  connect(this.submissionPort, this.submissionStdout)

  if (mode == 'verify')
    connect(this.solutionPort, this.solutionStdout)
}

module.exports = exercise

==> expressworks-3.4.3.tgz: package/exercises/good_old_form/exercise.js <==
const qs            = require('querystring')
    , through2      = require('through2')
    , superagent    = require('superagent')
    , filecheck     = require('workshopper-exercise/filecheck')
    , execute       = require('workshopper-exercise/execute')
    , comparestdout = require('workshopper-exercise/comparestdout')
    , rndport       = require('../../lib/rndport')

let exercise        = require('workshopper-exercise')()

// checks that the submission file actually exists
exercise = filecheck(exercise)

// execute the solution and submission in parallel with spawn()
exercise = execute(exercise)

// set up ports to be passed to submission and solution
exercise.addSetup(function(mode, callback) {
  this.submissionPort = rndport()
  this.solutionPort   = this.submissionPort + 1

  this.submissionArgs = [this.submissionPort]
  this.solutionArgs   = [this.solutionPort]

  process.nextTick(callback)
})

// add a processor for both run and verify calls, added *before*
// the comparestdout processor so we can mess with the stdouts
exercise.addProcessor(function (mode, callback) {
  this.submissionStdout.pipe(process.stdout)

  // replace stdout with our own streams
  this.submissionStdout = through2()
  if (mode == 'verify')
    this.solutionStdout = through2()

  setTimeout(query.bind(this, mode), 1500)

  process.nextTick(function () {
    callback(null, true)
  })
})


// compare stdout of solution and submission
exercise = comparestdout(exercise)

// delayed for 500ms to wait for servers to start so we can start
// playing with them
function query (mode) {
  const exercise = this

  function connect (port, stream) {
    const url = 'http://localhost:' + port + '/form'
    const text = exercise.__('exercises.good_old_form.source').split('').reverse().join('');

    superagent
      .post(url)
      .type('form')
      .send({str: text})
      .pipe(stream)
  }

  connect(this.submissionPort, this.submissionStdout)

  if (mode == 'verify')
    connect(this.solutionPort, this.solutionStdout)
}

module.exports = exercise
